@@ -3,7 +3,7 @@ package Data::ULID;
 use strict;
 use warnings;
 
-our $VERSION = '1.1.1';
+our $VERSION = '1.1.2';
 
 use base qw(Exporter);
 our @EXPORT_OK = qw/ulid binary_ulid ulid_date ulid_to_uuid uuid_to_ulid/;
@@ -375,5 +375,9 @@ same terms as Perl itself.
  0.4   - Bugfix: 'Invalid argument supplied to Math::GMPz::overload_mod' for
          older versions of Math::GMPz on Windows and FreeBSD. Podfix.
  1.0.0 - UUID conversion support; semantic versioning.
+ 1.1.0 - Speedups courtesy of Bartosz Jarzyna (brtastic on CPAN, bbrtj on
+         Github). Use Crypt::PRNG for random number generation.
+ 1.1.1 - Fix module version number.
+ 1.1.2 - Fix POD (version history).
 
 =cut
